CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C                                                                     C
C                            Pio (Fortran)                            C
C                                                                     C
C                    Polyglot Input/Output Library                    C
C                                                                     C
C                  projet Estime, INRIA-Rocquencourt                  C
C                                                                     C
C  Copyright 2004-2011 INRIA.                                         C
C  Institut National de Recherche en Informatique et en Automatique.  C
C  All rights reserved. This file is distributed only by permission.  C
C                                                                     C
C  Francois Clement <Francois.Clement@inria.fr>                       C
C  Pierre Weis <Pierre.Weis@inria.fr>                                 C
C  Hend Ben Ameur <hbenameur@yahoo.ca>                                C
C                                                                     C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC

C $Id: write_memory.F,v 1.5 2011-03-24 16:16:00 fclement Exp $

#include "pio_constants.h"

      subroutine write_memory_location(sbr, io, loc)
C     
      
      implicit none
      
C     Input arguments.
      character sbr*(*)
      integer io, loc
      
C     Local variable.
      character byt
      
C     External function.
      character rand_fetch_char
      
      byt = rand_fetch_char(sbr, io, loc)
      
      write(PIO_REPORT, *) 'loc ', loc, ': |', byt, '|'
      
      return
      end
      
      
      subroutine write_communication_name(io)
C     Write the name of the communication.
      
      implicit none
      
C     Input argument.
      integer io
      
C     Local variables.
      character sbr*24, cname*PIO_MAX_IDENT_LENGTH
      integer tc, bn, en, len
      
C     External functions.
      integer fetch_communication_type
      integer fetch_communication_name_begin
      integer fetch_communication_name_end
      
      sbr = 'write_communication_name'
      
      tc = fetch_communication_type(sbr, io)
      
      if ((tc .eq. PIO_TASK) .or. (tc .eq. PIO_SERVICE)) then
         
         bn = fetch_communication_name_begin(sbr, io)
         en = fetch_communication_name_end(sbr, io)
         
         len = en - bn
         call rand_fetch_string(sbr, io, bn, cname, 1, len)
         
         write(PIO_REPORT, *) ' '
         write(PIO_REPORT, *)
     +        '  Communication_Name [', bn, '; ', en, '[ = ',
     +        '"', cname(1:len), '"'
         
      endif
      
      return
      end

      
      subroutine write_string_value(io, i)
C     Write a string value.
      
      implicit none
      
C     Input arguments.
      integer io, i
      
C     Local variables.
      character sbr*18, sdatum*MAX_STRING_LENGTH
      integer len
      
      sbr = 'write_string_value'
      
      len = MAX_STRING_LENGTH
      
      call rand_fetch_string_value(sbr, io, i, sdatum, len)
      
      write(PIO_REPORT, *) '    "', sdatum(1:len), '"'
      
      return
      end
      
      
      subroutine write_int_value(io, i)
C     Write an int value.
      
      implicit none
      
C     Input arguments.
      integer io, i
      
C     Local variables.
      character sbr*15
      integer idatum
      
C     External function.
      integer rand_fetch_int_value
      
      sbr = 'write_int_value'
      
      idatum = rand_fetch_int_value(sbr, io, i, 1, 1, 1, 1, 1)
      
      write(PIO_REPORT, *) '    ', idatum
      
      return
      end
      
      
      subroutine write_float_value(io, i)
C     Write a float value.
      
      implicit none
      
C     Input arguments.
      integer io, i
      
C     Local variables.
      character sbr*17
      FLOAT fdatum
      
C     External function.
      FLOAT rand_fetch_float_value
      
      sbr = 'write_float_value'
      
      fdatum = rand_fetch_float_value(sbr, io, i, 1, 1, 1, 1, 1)
      
      write(PIO_REPORT, 1001) fdatum
 1001 format (4x,PRINT_FLOAT_FORMAT)
      
      return
      end
      
      
      subroutine write_scalar_simple_value(io, i, typ)
C     Write a scalar simple value.
      
      implicit none
      
C     Input arguments.
      integer io, i, typ
      
C     Local variable.
      character sbr*25
      
C     External functions.
      logical pio_get_debug_mode
      logical is_scalar_simple_string_type
      logical is_scalar_simple_int_type
      logical is_scalar_simple_float_type
      
      sbr = 'write_scalar_simple_value'
      
      if (pio_get_debug_mode()) then
         write(PIO_DEBUG, *) 'In ', sbr, ': typ = ', typ
      endif
      
      if (is_scalar_simple_string_type(typ)) then
         call write_string_value(io, i)
      else if (is_scalar_simple_int_type(typ)) then
         call write_int_value(io, i)
      else if (is_scalar_simple_float_type(typ)) then
         call write_float_value(io, i)
      else
         write(PIO_STDERR, *)
     +        'Unknown scalar simple value type ', typ, '.'
      endif
      
      return
      end
      
      
      subroutine write_string_couple_value(io, i)
C     Write an int couple value.
      
      implicit none
      
C     Input arguments.
      integer io, i
      
C     Local variables.
      character sbr*25, scdatum(2)*MAX_STRING_LENGTH
      integer clen(2)
      
      sbr = 'write_string_couple_value'
      
      call rand_fetch_string_compound_value
     +     (sbr, io, i, 2, clen, scdatum)
      
      write(PIO_REPORT, *) '    (', scdatum(1), ', ', scdatum(2), ')'
      
      return
      end
      
      
      subroutine write_int_couple_value(io, i)
C     Write an int couple value.
      
      implicit none
      
C     Input arguments.
      integer io, i
      
C     Local variables.
      character sbr*22
      integer n, icdatum(2)
      
C     External function.
      logical pio_get_debug_mode
      
      sbr = 'write_int_couple_value'
      
      if (pio_get_debug_mode()) then
         write(PIO_DEBUG, *) 'In ', sbr
      endif
      
      n = 2
      call rand_fetch_int_compound_value(sbr, io, i, n, icdatum)
      
      write(PIO_REPORT, *) '    (', icdatum(1), ', ', icdatum(2), ')'
      
      return
      end
      
      
      subroutine write_float_couple_value(io, i)
C     Write a float couple value.
      
      implicit none
      
C     Input arguments.
      integer io, i
      
C     Local variables.
      character sbr*24
      integer n
      FLOAT fcdatum(2)
      
      sbr = 'write_float_couple_value'
      
      n = 2
      call rand_fetch_float_compound_value(sbr, io, i, n, fcdatum)
      
      write(PIO_REPORT, 1001) fcdatum(1), fcdatum(2)
 1001 format ('    (',PRINT_FLOAT_FORMAT,', ',PRINT_FLOAT_FORMAT,')')

      return
      end
      
      
      subroutine write_scalar_couple_value(io, i, typ)
C     Write a scalar couple value.
      
      implicit none
      
C     Input arguments.
      integer io, i, typ
      
C     External functions.
      logical is_scalar_simple_string_type
      logical is_scalar_simple_int_type
      logical is_scalar_simple_float_type
      
      if (is_scalar_simple_string_type(typ)) then
         call write_string_couple_value(io, i)
      else if (is_scalar_simple_int_type(typ)) then
         call write_int_couple_value(io, i)
      else if (is_scalar_simple_float_type(typ)) then
         call write_float_couple_value(io, i)
      else
         write(PIO_STDERR, *)
     +        'Unknown scalar simple value type ', typ, '.'
      endif
      
      return
      end
      
      
      subroutine write_string_triple_value(io, i)
C     Write a string triple value.
      
      implicit none
      
C     Input arguments.
      integer io, i
      
C     Local variables.
      character sbr*25, stdatum(3)*MAX_STRING_LENGTH
      integer tlen(3)
      
      sbr = 'write_string_triple_value'
      
      tlen(1) = MAX_STRING_LENGTH
      tlen(2) = MAX_STRING_LENGTH
      tlen(3) = MAX_STRING_LENGTH
      
      call rand_fetch_string_compound_value
     +     (sbr, io, i, 3, tlen, stdatum)
      
      write(PIO_REPORT, *) '    ("', stdatum(1)(1:tlen(1)), '", "',
     +     stdatum(2)(1:tlen(2)), '", "', stdatum(3)(1:tlen(3)), '")'
      
      return
      end
      
      
      subroutine write_int_triple_value(io, i)
C     Write an int triple value.
      
      implicit none
      
C     Input arguments.
      integer io, i
      
C     Local variables.
      character sbr*22
      integer n, itdatum(3)
      
      sbr = 'write_int_triple_value'
      
      n = 3
      call rand_fetch_int_compound_value(sbr, io, i, n, itdatum)
      
      write(PIO_REPORT, *) '    (', itdatum(1), ', ', itdatum(2),
     +     ', ', itdatum(3), ')'
      
      return
      end
      
      
      subroutine write_float_triple_value(io, i)
C     Write a float triple value.
      
      implicit none
      
C     Input arguments.
      integer io, i
      
C     Local variables.
      character sbr*24
      integer n
      FLOAT ftdatum(3)
      
      sbr = 'write_float_triple_value'
      
      n = 3
      call rand_fetch_float_compound_value(sbr, io, i, n, ftdatum)
      
      write(PIO_REPORT, 1001) ftdatum(1), ftdatum(2), ftdatum(3)
 1001 format ('    (',PRINT_FLOAT_FORMAT, ', ',PRINT_FLOAT_FORMAT,
     +     ', ',PRINT_FLOAT_FORMAT, ')')

      return
      end
      
      
      subroutine write_scalar_triple_value(io, i, typ)
C     Write a scalar triple value.
      
      implicit none
      
C     Input arguments.
      integer io, i, typ
      
C     External functions.
      logical is_scalar_simple_string_type
      logical is_scalar_simple_int_type
      logical is_scalar_simple_float_type
      
      if (is_scalar_simple_string_type(typ)) then
         call write_string_triple_value(io, i)
      else if (is_scalar_simple_int_type(typ)) then
         call write_int_triple_value(io, i)
      else if (is_scalar_simple_float_type(typ)) then
         call write_float_triple_value(io, i)
      else
         write(PIO_STDERR, *)
     +        'Unknown scalar simple value type ', typ, '.'
      endif
      
      return
      end
      
      
      subroutine write_scalar_value(io, i, typ)
C     Write a scalar value.
      
      implicit none
      
C     Input arguments.
      integer io, i, typ
      
C     Local variables.
      character sbr*18
      integer item_typ
      
C     External functions.
      logical pio_get_debug_mode
      logical is_scalar_simple_type
      logical is_scalar_couple_type
      logical is_scalar_triple_type
      
      sbr = 'write_scalar_value'
      
      item_typ = MAKE_SCALAR_SIMPLE_ITEM_TYPE(typ)
      
      if (pio_get_debug_mode()) then
         write(PIO_DEBUG, *) 'In ', sbr, ': item_typ = ', item_typ
      endif
      
      if (is_scalar_simple_type(typ)) then
         call write_scalar_simple_value(io, i, item_typ)
      else if (is_scalar_couple_type(typ)) then
         call write_scalar_couple_value(io, i, item_typ)
      else if (is_scalar_triple_type(typ)) then
         call write_scalar_triple_value(io, i, item_typ)
      else
         write(PIO_STDERR, *) 'Unknown scalar value type ', typ, '.'
      endif
      
      return
      end
      
      
      subroutine write_string_vector_simple_value(io, i, sizev)
C     Write a string vector simple value.
      
      implicit none
      
C     Input arguments.
      integer io, i, sizev
      
C     Local variables.
      character sbr*32, svdatum(MAX_VECTOR_SIZE)*MAX_STRING_LENGTH
      integer vlen(MAX_VECTOR_SIZE), j
      
      sbr = 'write_string_vector_simple_value'
      
      do j = 1, sizev
         vlen(j) = MAX_STRING_LENGTH
      enddo
      
      call rand_fetch_string_compound_value
     +     (sbr, io, i, sizev, vlen, svdatum)
      
      write(PIO_REPORT, *) '    [|'
      do j = 1, sizev
         write(PIO_REPORT, *) '      "', svdatum(j)(1:vlen(j)), '";'
      enddo
      write(PIO_REPORT, *) '    |]'
      
      return
      end
      
      
      subroutine write_int_vector_simple_value(io, i, sizev)
C     Write an integer vector simple value.
      
      implicit none
      
C     Input arguments.
      integer io, i, sizev
      
C     Local variables.
      character sbr*29
      integer ivdatum(MAX_VECTOR_SIZE), j
      
      sbr = 'write_int_vector_simple_value'
      
      call rand_fetch_int_compound_value(sbr, io, i, sizev, ivdatum)
      
      write(PIO_REPORT, *) '    [|'
      do j = 1, sizev
         write(PIO_REPORT, *) '      ', ivdatum(j), ';'
      enddo
      write(PIO_REPORT, *) '    |]'
      
      return
      end
      
      
      subroutine write_float_vector_simple_value(io, i, sizev)
C     Write a float vector simple value.
      
      implicit none
      
C     Input arguments.
      integer io, i, sizev
      
C     Local variables.
      character sbr*31
      integer j
      FLOAT fvdatum(MAX_VECTOR_SIZE)
      
      sbr = 'write_float_vector_simple_value'
      
      call rand_fetch_float_compound_value(sbr, io, i, sizev, fvdatum)
      
      write(PIO_REPORT, *) '    [|'
      do j = 1, sizev
         write(PIO_REPORT, 1001) fvdatum(j)
      enddo
      write(PIO_REPORT, *) '    |]'
 1001 format (6x,PRINT_FLOAT_FORMAT,';')
      
      return
      end
      
      
      subroutine write_vector_simple_value(io, i, typ, sizev)
C     Write a vector simple value.
      
      implicit none
      
C     Input arguments.
      integer io, i, typ, sizev
      
C     Local variable.
C      character sbr*25
      
C     External functions.
      logical is_scalar_simple_string_type
      logical is_scalar_simple_int_type
      logical is_scalar_simple_float_type
      
C      sbr = 'write_vector_simple_value'
      
      if (is_scalar_simple_string_type(typ)) then
         call write_string_vector_simple_value(io, i, sizev)
      else if (is_scalar_simple_int_type(typ)) then
         call write_int_vector_simple_value(io, i, sizev)
      else if (is_scalar_simple_float_type(typ)) then
         call write_float_vector_simple_value(io, i, sizev)
      else
         write(PIO_STDERR, *)
     +        'Unknown vector simple value type ', typ, '.'
      endif
      
      return
      end
      
      
      subroutine write_vector_value(io, i, typ)
C     Write a vector value.
      
      implicit none
      
C     Input arguments.
      integer io, i, typ
      
C     Local variables.
      character sbr*18
      integer item_typ, pv, sizev(MAX_ARRAY_DIMENSION)
      
C     External functions.
      logical is_vector_simple_type
      logical is_vector_couple_type
      logical is_vector_triple_type
      integer fetch_value_dimension
      
      sbr = 'write_vector_value'
      
      item_typ = MAKE_VECTOR_ITEM_TYPE(typ)
      pv = fetch_value_dimension(sbr, io, i)
      if (pv .ne. 1) then
         call error_wrong_dimension(sbr, 1, pv)
      endif
      call fetch_value_sizes(sbr, io, i, sizev(1))
      if (sizev(1) .gt. MAX_VECTOR_SIZE) then
         call error_too_large_size(sbr, MAX_VECTOR_SIZE, sizev(1))
      endif
      
      if (is_vector_simple_type(typ)) then
         call write_vector_simple_value(io, i, item_typ, sizev(1))
      else if (is_vector_couple_type(typ)) then
         continue
      else if (is_vector_triple_type(typ)) then
         continue
      else
         write(PIO_STDERR, *) 'Unknown vector value type ', typ, '.'
      endif
      
      return
      end

      
C      subroutine write_multi_d_value(io, i, typ)
      subroutine write_multi_d_value
C     Write a multi-dimensional value.
      
      implicit none
      
C     Input arguments.
C      integer io, i, typ
      
C     Local variables.
C      character sbr*19
      
C      sbr = 'write_multi_d_value'
      
      return
      end

      
      subroutine write_value(io, i)
C     Write ith value.
      
      implicit none
      
C     Input argument.
      integer io, i
      
C     Local variables.
      character sbr*11
      integer tv, bv, ev
      
C     External functions.
      logical is_scalar_type, is_vector_type, is_multi_d_type
      integer fetch_value_type, fetch_value_begin, fetch_value_end
      
      sbr = 'write_value'
      
      tv = fetch_value_type(sbr, io, i)
      
      bv = fetch_value_begin(sbr, io, i)
      ev = fetch_value_end(sbr, io, i)
      
      write(PIO_REPORT, *) '  Value [', bv, '; ', ev, '[ ='
      
      if (is_scalar_type(tv)) then
         call write_scalar_value(io, i, tv)
      else if (is_vector_type(tv)) then
         call write_vector_value(io, i, tv)
      else if (is_multi_d_type(tv)) then
C         call write_multi_d_value(io, i, tv)
         call write_multi_d_value
      else
         write(PIO_STDERR, *) 'Unknown value type ', tv, '.'
      endif
      
      
      return
      end

      
      subroutine write_values(io)
C     Write all the values.
      
      implicit none
      
C     Input argument.
      integer io
      
C     Local variables.
      character sbr*12
      integer nv, i
      
C     External function.
      integer fetch_communication_values_number
      
      sbr = 'write_values'
      
      nv = fetch_communication_values_number(sbr, io)
      
      do i = 1, nv
         write(PIO_REPORT, *) ' '
         write(PIO_REPORT, *) '  Value number ', i
         call write_value(io, i)
      enddo
      
      return
      end

      
      subroutine pio_write_memory(io)
C     Write the contents of the memory to stderr.
      
      implicit none
      
      include 'memory_name_definition.fh'
      
C     Input argument.
      integer io
      
      write(PIO_REPORT, *) memory_name(io+2), ' memory begins'
      
      call write_communication_name(io)
      call write_values(io)
      
      write(PIO_REPORT, *) ' '
      write(PIO_REPORT, *) memory_name(io+2), ' memory ends.'
      
      return
      end
